Assorted spelling fixes

Francois Gouget fgouget at free.fr
Tue Mar 21 11:24:49 CST 2006


Changelog:

  * dlls/ddraw/tests/ddrawmodes.c
    dlls/ole32/datacache.c
    dlls/ole32/storage32.c
    dlls/oleaut32/dispatch.c
    dlls/shell32/shlfolder.c
    dlls/shlwapi/ordinal.c
    dlls/shlwapi/path.c
    dlls/wininet/gopher.c

    Francois Gouget <fgouget at free.fr>
    Assorted spelling fixes.

-- 
Francois Gouget <fgouget at free.fr>              http://fgouget.free.fr/
                             $live{free} || die "";
-------------- next part --------------
Index: dlls/ole32/datacache.c
===================================================================
RCS file: /home/wine/wine/dlls/ole32/datacache.c,v
retrieving revision 1.36
diff -u -p -r1.36 datacache.c
--- dlls/ole32/datacache.c	28 Sep 2005 18:12:58 -0000	1.36
+++ dlls/ole32/datacache.c	21 Mar 2006 14:29:09 -0000
@@ -338,7 +338,7 @@ static BOOL DataCache_IsPresentationStre
  * Notes:
  *   Algorithm:	Scan the elements of the presentation storage, looking
  *		for presentation streams. For each presentation stream,
- *		load the header and check to see if the aspect maches.
+ *		load the header and check to see if the aspect matches.
  *
  *   If a fallback is desired, just opening the first presentation stream
  *   is a possibility.
@@ -960,7 +960,7 @@ static HRESULT WINAPI DataCache_GetClass
 /************************************************************************
  * DataCache_IsDirty (IPersistStorage)
  *
- * Until we actully connect to a running object and retrieve new
+ * Until we actually connect to a running object and retrieve new
  * information to it, we never get dirty.
  *
  * See Windows documentation for more details on IPersistStorage methods.
@@ -1025,9 +1025,9 @@ static HRESULT WINAPI DataCache_Load(
 /************************************************************************
  * DataCache_Save (IPersistStorage)
  *
- * Until we actully connect to a running object and retrieve new
+ * Until we actually connect to a running object and retrieve new
  * information to it, we never have to save anything. However, it is
- * our responsability to copy the information when saving to a new
+ * our responsibility to copy the information when saving to a new
  * storage.
  *
  * See Windows documentation for more details on IPersistStorage methods.
@@ -1058,7 +1058,7 @@ static HRESULT WINAPI DataCache_Save(
  * DataCache_SaveCompleted (IPersistStorage)
  *
  * This method is called to tell the cache to release the storage
- * pointer it's currentlu holding.
+ * pointer it's currently holding.
  *
  * See Windows documentation for more details on IPersistStorage methods.
  */
@@ -1090,7 +1090,7 @@ static HRESULT WINAPI DataCache_SaveComp
  * DataCache_HandsOffStorage (IPersistStorage)
  *
  * This method is called to tell the cache to release the storage
- * pointer it's currentlu holding.
+ * pointer it's currently holding.
  *
  * See Windows documentation for more details on IPersistStorage methods.
  */
@@ -1809,7 +1809,7 @@ static DataCache* DataCache_Construct(
   /*
    * Initialize the outer unknown
    * We don't keep a reference on the outer unknown since, the way
-   * aggregation works, our lifetime is at least as large as it's
+   * aggregation works, our lifetime is at least as large as its
    * lifetime.
    */
   if (pUnkOuter==NULL)
Index: dlls/ole32/storage32.c
===================================================================
RCS file: /home/wine/wine/dlls/ole32/storage32.c,v
retrieving revision 1.102
diff -u -p -r1.102 storage32.c
--- dlls/ole32/storage32.c	24 Feb 2006 20:31:22 -0000	1.102
+++ dlls/ole32/storage32.c	21 Mar 2006 14:29:09 -0000
@@ -787,13 +787,13 @@ HRESULT WINAPI StorageBaseImpl_RenameEle
 
     /*
      * At this point the renamed property has been inserted in the tree,
-     * now, before to Destroy the old property we must zeroed it's dirProperty
+     * now, before Destroying the old property we must zero its dirProperty
      * otherwise the DestroyProperty below will zap it all and we do not want
      * this to happen.
      * Also, we fake that the old property is a storage so the DestroyProperty
      * will not do a SetSize(0) on the stream data.
      *
-     * This means that we need to tweek the StgProperty if it is a stream or a
+     * This means that we need to tweak the StgProperty if it is a stream or a
      * non empty storage.
      */
     StorageImpl_ReadProperty(This->ancestorStorage,
@@ -809,7 +809,7 @@ HRESULT WINAPI StorageBaseImpl_RenameEle
 
     /*
      * Invoke Destroy to get rid of the ole property and automatically redo
-     * the linking of it's previous and next members...
+     * the linking of its previous and next members...
      */
     IStorage_DestroyElement((IStorage*)This->ancestorStorage, pwcsOldName);
 
@@ -1429,7 +1429,7 @@ static void updatePropertyChain(
   else
   {
     /*
-     * The root storage is empty, link the new property to it's dir property
+     * The root storage is empty, link the new property to its dir property
      */
     currentProperty.dirProperty = newPropertyIndex;
     StorageImpl_WriteProperty(storage->base.ancestorStorage,
@@ -1652,12 +1652,12 @@ HRESULT WINAPI StorageImpl_Revert(
 /*************************************************************************
  * DestroyElement (IStorage)
  *
- * Stategy: This implementation is build this way for simplicity not for speed.
- *          I always delete the top most element of the enumeration and adjust
+ * Strategy: This implementation is built this way for simplicity not for speed.
+ *          I always delete the topmost element of the enumeration and adjust
  *          the deleted element pointer all the time.  This takes longer to
  *          do but allow to reinvoke DestroyElement whenever we encounter a
- *          storage object.  The optimisation reside in the usage of another
- *          enumeration stategy that would give all the leaves of a storage
+ *          storage object.  The optimisation resides in the usage of another
+ *          enumeration strategy that would give all the leaves of a storage
  *          first. (postfix order)
  */
 HRESULT WINAPI StorageImpl_DestroyElement(
@@ -1706,7 +1706,7 @@ HRESULT WINAPI StorageImpl_DestroyElemen
   /*
    * Find the parent property of the property to delete (the one that
    * link to it).  If This->dirProperty == foundPropertyIndexToDelete,
-   * the parent is This. Otherwise, the parent is one of it's sibling...
+   * the parent is This. Otherwise, the parent is one of its sibling...
    */
 
   /*
@@ -1902,7 +1902,7 @@ static HRESULT deleteStorageProperty(
   } while ((hr == S_OK) && (destroyHr == S_OK));
 
   /*
-   * Invalidate the property by zeroing it's name member.
+   * Invalidate the property by zeroing its name member.
    */
   propertyToDelete.sizeOfNameString = 0;
 
@@ -1964,7 +1964,7 @@ static HRESULT deleteStreamProperty(
   IStream_Release(pis);
 
   /*
-   * Invalidate the property by zeroing it's name member.
+   * Invalidate the property by zeroing its name member.
    */
   propertyToDelete.sizeOfNameString = 0;
 
@@ -5599,7 +5599,7 @@ ULARGE_INTEGER SmallBlockChainStream_Get
  *  ppstgOpen [IO] A pointer to IStorage pointer to the new onject
  *
  * RETURNS
- *  S_OK if the file was succesfully created
+ *  S_OK if the file was successfully created
  *  some STG_E_ value if error
  * NOTES
  *  if pwcsName is NULL, create file with new unique name
Index: dlls/oleaut32/dispatch.c
===================================================================
RCS file: /home/wine/wine/dlls/oleaut32/dispatch.c,v
retrieving revision 1.28
diff -u -p -r1.28 dispatch.c
--- dlls/oleaut32/dispatch.c	22 Sep 2005 10:44:40 -0000	1.28
+++ dlls/oleaut32/dispatch.c	21 Mar 2006 14:29:09 -0000
@@ -85,7 +85,7 @@ HRESULT WINAPI DispInvoke(
 /******************************************************************************
  *		DispGetIDsOfNames (OLEAUT32.29)
  *
- * Convert a set of parameter names to DISPID's for DispInvoke().
+ * Convert a set of parameter names to DISPIDs for DispInvoke().
  *
  * RETURNS
  *  Success: S_OK.
@@ -93,13 +93,13 @@ HRESULT WINAPI DispInvoke(
  *
  * NOTES
  *  This call defers to ITypeInfo_GetIDsOfNames(). The ITypeInfo interface passed
- *  as ptinfo contains the information to map names to DISPID's.
+ *  as ptinfo contains the information to map names to DISPIDs.
  */
 HRESULT WINAPI DispGetIDsOfNames(
 	ITypeInfo  *ptinfo,    /* [in] Object's type info */
-	OLECHAR   **rgszNames, /* [in] Array of names to get DISPID's for */
+	OLECHAR   **rgszNames, /* [in] Array of names to get DISPIDs for */
 	UINT        cNames,    /* [in] Number of names in rgszNames */
-	DISPID     *rgdispid)  /* [out] Destination for converted DISPID's */
+	DISPID     *rgdispid)  /* [out] Destination for converted DISPIDs */
 {
     return ITypeInfo_GetIDsOfNames(ptinfo, rgszNames, cNames, rgdispid);
 }
@@ -107,7 +107,7 @@ HRESULT WINAPI DispGetIDsOfNames(
 /******************************************************************************
  *		DispGetParam (OLEAUT32.28)
  *
- * Retrive a parameter from a DISPPARAMS structure and coerce it to the
+ * Retrieve a parameter from a DISPPARAMS structure and coerce it to the
  * specified variant type.
  *
  * NOTES
@@ -203,10 +203,10 @@ HRESULT WINAPI CreateStdDispatch(
  *  to simplify the process of calling an objects methods through IDispatch.
  *
  *  A standard implementation of an IDispatch object is created by calling
- *  CreateStdDispatch(). Numeric Id values for the parameters and methods (DISPID's)
+ *  CreateStdDispatch(). Numeric Id values for the parameters and methods (DISPIDs)
  *  of an object of interest are retrieved by calling DispGetIDsOfNames(). DispGetParam()
  *  retrieves information about a particular parameter. Finally the DispInvoke()
- *  function is responsable for actually calling methods on an object.
+ *  function is responsible for actually calling methods on an object.
  *
  * METHODS
  */
@@ -342,7 +342,7 @@ static HRESULT WINAPI StdDispatch_GetTyp
 /******************************************************************************
  * IDispatch_GetIDsOfNames {OLEAUT32}
  *
- * Convert a methods name and an optional set of parameter names into DISPID's
+ * Convert a methods name and an optional set of parameter names into DISPIDs
  * for passing to IDispatch_Invoke().
  *
  * PARAMS
@@ -351,7 +351,7 @@ static HRESULT WINAPI StdDispatch_GetTyp
  *  rgszNames [I] Name to convert
  *  cNames    [I] Number of names in rgszNames
  *  lcid      [I] Locale of the type information to convert from
- *  rgDispId  [O] Destination for converted DISPID's.
+ *  rgDispId  [O] Destination for converted DISPIDs.
  *
  * RETURNS
  *  Success: S_OK.
Index: dlls/shell32/shlfolder.c
===================================================================
RCS file: /home/wine/wine/dlls/shell32/shlfolder.c,v
retrieving revision 1.111
diff -u -p -r1.111 shlfolder.c
--- dlls/shell32/shlfolder.c	20 Feb 2006 11:43:13 -0000	1.111
+++ dlls/shell32/shlfolder.c	21 Mar 2006 14:29:10 -0000
@@ -109,7 +109,7 @@ BOOL SHELL32_GetCustomFolderAttribute(
 /***************************************************************************
  *  GetNextElement (internal function)
  *
- * gets a part of a string till the first backslash
+ * Gets a part of a string till the first backslash.
  *
  * PARAMETERS
  *  pszNext [IN] string to get the element from
@@ -190,7 +190,7 @@ HRESULT SHELL32_ParseNextElement (IShell
  *
  * NOTES
  *   pathRoot can be NULL for Folders beeing a drive.
- *   In this case the absolute path is build from pidlChild (eg. C:)
+ *   In this case the absolute path is built from pidlChild (eg. C:)
  */
 static HRESULT SHELL32_CoCreateInitSF (LPCITEMIDLIST pidlRoot, LPCWSTR pathRoot,
     LPCITEMIDLIST pidlChild, REFCLSID clsid, REFIID riid, LPVOID * ppvOut)
@@ -319,7 +328,7 @@ HRESULT SHELL32_BindToChild (LPCITEMIDLI
 /***********************************************************************
  *	SHELL32_GetDisplayNameOfChild
  *
- * Retrives the display name of a child object of a shellfolder.
+ * Retrieves the display name of a child object of a shellfolder.
  *
  * For a pidl eg. [subpidl1][subpidl2][subpidl3]:
  * - it binds to the child shellfolder [subpidl1]
@@ -368,7 +377,7 @@ HRESULT SHELL32_GetDisplayNameOfChild (I
  *  SHELL32_GetItemAttributes
  *
  * NOTES
- * observerd values:
+ * Observed values:
  *  folder:	0xE0000177	FILESYSTEM | HASSUBFOLDER | FOLDER
  *  file:	0x40000177	FILESYSTEM
  *  drive:	0xf0000144	FILESYSTEM | HASSUBFOLDER | FOLDER | FILESYSANCESTOR
@@ -380,7 +389,7 @@ HRESULT SHELL32_GetDisplayNameOfChild (I
  *  file:      0x40400177      FILESYSTEM | CANMONIKER
  *  drive      0xF0400154      FILESYSTEM | HASSUBFOLDER | FOLDER | FILESYSANCESTOR | CANMONIKER | CANRENAME (LABEL)
  *
- * According to the MSDN documentation this function should not set flags. It claimes only to reset flags when necessary.
+ * According to the MSDN documentation this function should not set flags. It claims only to reset flags when necessary.
  * However it turns out the native shell32.dll _sets_ flags in several cases - so do we.
  */
 HRESULT SHELL32_GetItemAttributes (IShellFolder * psf, LPCITEMIDLIST pidl, LPDWORD pdwAttributes)
Index: dlls/shlwapi/ordinal.c
===================================================================
RCS file: /home/wine/wine/dlls/shlwapi/ordinal.c,v
retrieving revision 1.118
diff -u -p -r1.118 ordinal.c
--- dlls/shlwapi/ordinal.c	6 Feb 2006 13:35:57 -0000	1.118
+++ dlls/shlwapi/ordinal.c	21 Mar 2006 14:29:11 -0000
@@ -1267,7 +1267,7 @@ HWND WINAPI SHSetParentHwnd(HWND hWnd, H
  *
  * RETURNS
  *  Success: S_OK. If lppCP is non-NULL, it is filled with the IConnectionPoint
- *           that was advised. The caller is responsable for releasing it.
+ *           that was advised. The caller is responsible for releasing it.
  *  Failure: E_FAIL, if any arguments are invalid.
  *           E_NOINTERFACE, if lpUnknown isn't an IConnectionPointContainer,
  *           Or an HRESULT error code if any call fails.
Index: dlls/shlwapi/path.c
===================================================================
RCS file: /home/wine/wine/dlls/shlwapi/path.c,v
retrieving revision 1.55
diff -u -p -r1.55 path.c
--- dlls/shlwapi/path.c	22 Feb 2006 11:45:20 -0000	1.55
+++ dlls/shlwapi/path.c	21 Mar 2006 14:29:11 -0000
@@ -2519,7 +2519,7 @@ LPWSTR WINAPI PathFindNextComponentW(LPC
  * RETURNS
  *  TRUE  If the path was modified,
  *  FALSE If lpszPath or lpszExtension are invalid, lpszPath has an
- *        extension allready, or the new path length is too big.
+ *        extension already, or the new path length is too big.
  *
  * FIXME
  *  What version of shlwapi.dll adds "exe" if lpszExtension is NULL? Win2k
Index: dlls/wininet/gopher.c
===================================================================
RCS file: /home/wine/wine/dlls/wininet/gopher.c,v
retrieving revision 1.2
diff -u -p -r1.2 gopher.c
--- dlls/wininet/gopher.c	14 Feb 2006 13:32:19 -0000	1.2
+++ dlls/wininet/gopher.c	21 Mar 2006 14:29:12 -0000
@@ -93,7 +93,7 @@ BOOL WINAPI GopherCreateLocatorW(
  *                      - Locator created by the GopherCreateLocator function.
  * lpszSearchString [I] what to search for if this request is to an index server.
  *                      Otherwise, this parameter should be NULL.
- * lpFindData       [O] retrived information
+ * lpFindData       [O] retrieved information
  * dwFlags          [I] INTERNET_FLAG_{HYPERLINK, NEED_FILE, NO_CACHE_WRITE, RELOAD, RESYNCHRONIZE}
  * dwContext        [I] application private value
  *


More information about the wine-patches mailing list
Index: dlls/ddraw/tests/ddrawmodes.c
===================================================================
RCS file: /home/wine/wine/dlls/ddraw/tests/ddrawmodes.c,v
retrieving revision 1.9
diff -u -p -r1.9 ddrawmodes.c
--- dlls/ddraw/tests/ddrawmodes.c	12 Dec 2005 12:48:21 -0000	1.9
+++ dlls/ddraw/tests/ddrawmodes.c	21 Mar 2006 14:29:08 -0000
@@ -229,10 +229,10 @@ static void testcooperativelevels_normal
         hwnd, DDSCL_SETFOCUSWINDOW);
     ok(rc==DD_OK,"SetCooperativeLevel(DDSCL_SETFOCUSWINDOW) returned: %lx\n",rc);
 
     /* Set the focus window a secound time*/
     rc = IDirectDraw_SetCooperativeLevel(lpDD,
         hwnd, DDSCL_SETFOCUSWINDOW);
-    ok(rc==DD_OK,"SetCooperativeLevel(DDSCL_SETFOCUSWINDOW) the secound time returned: %lx\n",rc);
+    ok(rc==DD_OK,"SetCooperativeLevel(DDSCL_SETFOCUSWINDOW) the second time returned: %lx\n",rc);
 
     /* Test DDSCL_SETFOCUSWINDOW with the other flags. They should all fail, except of DDSCL_NOWINDOWCHANGES */
     rc = IDirectDraw_SetCooperativeLevel(lpDD,
@@ -229,10 +229,10 @@ static void testcooperativelevels_normal
     ok(rc==DD_OK,"SetCooperativeLevel(DDSCL_SETFOCUSWINDOW) returned: %lx\n",rc);
 
-    /* Set the focus window a secound time*/
+    /* Set the focus window a second time*/
     rc = IDirectDraw_SetCooperativeLevel(lpDD,
         hwnd, DDSCL_SETFOCUSWINDOW);